+++
title = "Taxonomy weights and page weight 4"
tags = ["weight", "taxonomy-weight", "manual", "tags", "page-weight", "categories"]
draft = false
categories_weight = 999
weight = 77
tags_weight = 111
+++

The page weight does not have to be specified as the very first weight
if using the `:page` keyword before the weight value.
